@@ -23,8 +23,6 @@ package WWW::TV::Series;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
-
 use Carp qw(croak);
 use LWP::UserAgent qw();
 
@@ -138,16 +136,13 @@ sub genres {
     return $self->{genres} if exists $self->{filled}->{genres};
     $self->{filled}->{genres} = 1;
 
-    my ($genres_row) = $self->_html =~ m{
-        Show\sCategories:\n
-        (<a\shref=.*</a>)
-    }x;
-
+    my @parts = split(/Show Categories:/, $self->_html);
+    my ($genres) = $parts[1] =~ /^(.*)\n/s if $parts[1];
     $self->{genres} =
         join(
-            ', ',
-            map { s/\s*<a href="[^"]+">(.*?)<\/a>\s*/$1/; $_ }
-            split(/,/, $genres_row)
+            ',',
+            map { s#<a href=.*?>(.*?)</a>#$1#; $_ }
+            split(/,/, $genres)
         );
 
     return $self->{genres};
@@ -174,7 +169,7 @@ sub cast {
         }x;
         push @cast, $1;
     }
-    $self->{cast} = join(', ', @cast);
+    $self->{cast} = join(',', @cast);
 
     return $self->{cast};
 }
@@ -191,32 +186,13 @@ sub name {
     $self->{filled}->{name} = 1;
 
     ($self->{name}) = $self->_html =~ m{
-        <div\sid="content-head".*?>\n\n?
+        <div\sid="content-head".*?>\n
         <h1>(.*?)</h1>\n
     }x;
 
     return $self->{name};
 }
 
-=head2 image
-
-    Returns the url of an image that can be used to identify this series.
-
-=cut
-
-sub image {
-    my ($self) = @_;
-    return $self->{image} if exists $self->{filled}->{image};
-    $self->{filled}->{image} = 1;
-
-    ($self->{image}) = $self->_html =~ m{
-        <a\sclass="default-image\smore"\shref=".+;image">\n
-        <img\ssrc="(.+)"\salt=".+"\s/>More\sPictures\s+</a>\n
-    }x;
-
-    return $self->{image};
-}
-
 =head2 episodes
 
     Returns an array of L<WWW::TV::Episode> objects in order.
@@ -237,7 +213,7 @@ sub episodes {
         grep { defined }
         map {
             my $ep;
-            if (m#<a href=".*/episode/(\d+)/summary\.html[^"]*">(.*)</a>#) {
+            if (m#<a href=".*/episode/(\d+)/summary.html">(.*)</a>#) {
                 $ep = WWW::TV::Episode->new(id => $1, name => $2);
             }
             $ep;
@@ -320,7 +296,7 @@ done transparently these days.
 =head1 BUGS
 
 Please report any bugs or feature requests to
-C<bug-WWW-TV@rt.cpan.org>, or through the web interface at
+C<bug-WWW-TV-Series@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 AUTHOR
